package App::optex::tc;

use v5.14;
use warnings;

use App::optex::textconv;

*initialize = \&App::optex::textconv::initialize;

1;
